Stan Math Library: stan/math/rev/mat/fun/mdivide_left_ldlt.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
mdivide_left_ldlt.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/rev/mat/fun/LDLT_alloc.hpp>`
`#include <stan/math/rev/mat/fun/LDLT_factor.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R1, int C1, int R2, int C2>
Eigen::Matrix< var, R1, C2 > | stan::math::mdivide_left_ldlt (const stan::math::LDLT_factor< var, R1, C1 > &A, const Eigen::Matrix< var, R2, C2 > &b)
| Returns the solution of the system Ax=b given an LDLT_factor of A. More...
template<int R1, int C1, int R2, int C2>
Eigen::Matrix< var, R1, C2 > | stan::math::mdivide_left_ldlt (const stan::math::LDLT_factor< var, R1, C1 > &A, const Eigen::Matrix< double, R2, C2 > &b)
| Returns the solution of the system Ax=b given an LDLT_factor of A. More...
template<int R1, int C1, int R2, int C2>
Eigen::Matrix< var, R1, C2 > | stan::math::mdivide_left_ldlt (const stan::math::LDLT_factor< double, R1, C1 > &A, const Eigen::Matrix< var, R2, C2 > &b)
| Returns the solution of the system Ax=b given an LDLT_factor of A. More...

## Variable Documentation

mdivide_left_ldlt_alloc<R1, C1, R2, C2>* _alloc

Definition at line 44 of file mdivide_left_ldlt.hpp.

const LDLT_alloc<R1, C1>* _alloc_ldlt

Definition at line 45 of file mdivide_left_ldlt.hpp.

boost::shared_ptr<Eigen::LDLT<Eigen::Matrix<double, R1, C1> > > _ldltP

This share_ptr is used to prevent copying the LDLT factorizations for mdivide_left_ldlt(ldltA, b) when ldltA is a LDLT_factor<double>.

The pointer is shared with the LDLT_factor<double> class.

Definition at line 23 of file mdivide_left_ldlt.hpp.

vari** _variRefB

Definition at line 42 of file mdivide_left_ldlt.hpp.

vari** _variRefC

Definition at line 43 of file mdivide_left_ldlt.hpp.

Eigen::Matrix<double, R2, C2> C_

Definition at line 24 of file mdivide_left_ldlt.hpp.

int M_

Definition at line 40 of file mdivide_left_ldlt.hpp.

int N_

Definition at line 41 of file mdivide_left_ldlt.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.